function varargout=configure(varargin)
% FUNCTION fc_siplt.configure()
%   Configures the toolbox/package by setting the <fc-simesh> toolbox/package directory.
%   Theses informations will be stored in ... file.
%
% <COPYRIGHT>
  [conffile,isFileExists]=fc_siplt.getLocalConfFile();
  if isFileExists
    run(conffile);
  else
    fullname=mfilename('fullpath');
    I=strfind(fullname,filesep);
    Path=fullname(1:(I(end-1)-1));
    fc_simesh_dir='';    % empty if pkg or toolbox in path
    fc_graphics4mesh_dir=''; % empty if pkg or toolbox in path
  end
  p = inputParser;
  p.addParamValue('fc_simesh_dir'   ,fc_simesh_dir,@ischar);
  p.addParamValue('fc_graphics4mesh_dir'   ,fc_graphics4mesh_dir,@ischar);
  p.parse(varargin{:});
  R=p.Results;
  
  R.fc_simesh_dir=get_pathtoolbox('simesh',R.fc_simesh_dir);
  R.fc_graphics4mesh_dir=get_pathtoolbox('graphics4mesh',R.fc_graphics4mesh_dir);
  fprintf('Write in %s ...\n',conffile);
  fid=fopen(conffile,'w');
  if (fid==0), error('Unable to open file :\n %s\n',conffile);end
  fprintf(fid,'%% Automaticaly generated with fc_siplt.configure()\n');
  fprintf(fid,'fc_simesh_dir=''%s'';\n',R.fc_simesh_dir);
  fprintf(fid,'fc_graphics4mesh_dir=''%s'';\n',R.fc_graphics4mesh_dir);
  fclose(fid);
  fprintf('  -> done\n');
  if nargout==1,varargout{1}=conffile;end
end

function out_dir=get_pathtoolbox(shortname,var_dir)
  if ~isempty(var_dir) 
    if ~exist(var_dir,'dir') 
      error('Directory %s doesn''t exist!', var_dir)
    end
    if check_toolbox(shortname)
      warning('The <fc-%s> toolbox/package is already in path!',shortname)
    else
      addpath(var_dir)
      if ~check_toolbox(shortname)
        error('Unable to load the <fc-%s> toolbox/package in directory:\n   %s\n',shortname,var_dir)
      end
      rmpath(var_dir)
      out_dir=var_dir;
    end
  else
    if check_toolbox(shortname)
      out_dir=eval('fc_%s.path()',shortname);
    else % try to guess
      fullname=mfilename('fullpath');
      I=strfind(fullname,filesep);
      apath=fullfile(fullname(1:(I(end-2)-1)),['fc-',shortname]);
      if exist(apath,'dir')
        addpath(apath)
        if ~check_toolbox(shortname)
          error('Unable to load the <fc-%s> toolbox/package in directory:\n   %s\n',shortname,apath)
        end
        rmpath(apath)
        out_dir=apath;
      else
        error('Unable to load the <fc-%s> toolbox/package in directory:\n   %s\n',shortname,apath)
      end
    end
  end
end

function res=check_toolbox(shortname)
  try 
    eval(['fc_',shortname,'.init()'])
  catch
    res=false;return;
  end
  res=true;
end